####################
# Copyright (c) 20010, Oliver Fueckert. All rights reserved.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
#
# IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
# INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
# NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
#
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
# NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN
# IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
####################

####################
## IMPORTS
import cherrypy
from cherrypy import _cperror

from indigopy import indigoconn as ic
from indigopy import indigodb as idb
from indigopy.basereqhandler import BaseRequestHandler, kTrueStr, kFalseStr, kEmptyStr, kTextPageStr, kHtmlPageStr, kXmlPageStr

import socket
import os
import os.path
import sys
import csv
import cgi
import urllib;
import time;

####################
# Optional hooks to provide a plugin name and description (shown in Event Log and plugin index)
def PluginName():
	return u"Indigo Cisco Phone Services"

def PluginDescription():
	return u"Let's you control your devices with Cisco Phone Services"

def ShowOnControlPageList():
	return True		# if True, then above name/description is shown on the Control Page list index

# Optional hook called when the IndigoWebServer first connects to IndigoServer
def IndigoConnected():
	pass

# Optional hook called when the IndigoWebServer disconnect from IndigoServer
def IndigoDisconnected():
	pass

class HaloHomeRequestHandler(BaseRequestHandler):

	def __init__(self, logFunc, debugLogFunc):
		BaseRequestHandler.__init__(self, logFunc, debugLogFunc)

	def index(self):
		# Override the returned content type to be plain text instead of HTML.
		cherrypy.response.headers['Content-Type'] = 'text/plain'
		return u"This directory only displays on Cisco IP Phones. Please configure http://server:port/CiscoServices/mainmenu as Services URL in your phone config file."
	index.exposed = True

###########################################################################
## Phone Main Menu
## 
## Shows Device, Actiongroups submenus, Actiongroup Names starting with "cphone.*"
## will be displayed in the main menu as well. Motion Sensors, I/O Links, etc should
## have Remote Display disabled in the Indigo Device View.
##	
	def mainmenu(self, locale=None, name=None, action=None, device=None, level=None, group=None, view="main"):
		
		ph_screen = cherrypy.request.headers.get('x-CiscoIPPhoneDisplay')
		ph_model = cherrypy.request.headers.get('x-CiscoIPPhoneModelName')
		ph_ip = cherrypy.request.remote.ip
		if ph_model:
			self._Log ("Access from Cisco Phone %s, Model %s, Screen size %s" % (ph_ip, ph_model, ph_screen))
		
		if action != None:
			try:
				if action == "turnon":
					cherrypy.server.indigoDb.DeviceTurnOn(cherrypy.server.indigoConn, device, cherrypy.request.remote.ip)
				elif action == "turnoff":
					cherrypy.server.indigoDb.DeviceTurnOff(cherrypy.server.indigoConn, device, cherrypy.request.remote.ip)
				elif action == "setbrightness":
					cherrypy.server.indigoDb.DeviceSetBrightness(cherrypy.server.indigoConn, device, level, cherrypy.request.remote.ip)
				elif action == "groupexecute":
					cherrypy.server.indigoDb.GroupExecute(cherrypy.server.indigoConn, group, cherrypy.request.remote.ip)
			except (ic.ConnError, ic.InternalError, ic.ServerError), err:
				return self._ReturnError(pageType, err.value)
			except idb.ControlDisabled:
				return self._ReturnControlDisabled(pageType)
			finally:
				time.sleep(1)
		## Write output to phone in XML
		cherrypy.response.headers['Content-Type'] = "text/xml"
		tmpl = self._GetAndLockPluginTemplate('CiscoServices/mainmenu.html')
		try:
			tmpl.view = view
			tmpl.devList = cherrypy.server.indigoDb.GetDevices(cherrypy.server.indigoConn, True)
			tmpl.actionGroupList = cherrypy.server.indigoDb.GetActionGroups(cherrypy.server.indigoConn, True, True)
			tmpl.variableList = cherrypy.server.indigoDb.GetVariables(cherrypy.server.indigoConn, True)
			tmpl.baseurl = cherrypy.request.base
			return tmpl.RenderTemplate()
		finally:
			tmpl.ReleaseLock();
	mainmenu.exposed = True

	def imagemenu(self):
		# Override the returned content type to be plain text instead of HTML.
		cherrypy.response.headers['Content-Type'] = 'text/xml'
		tmpl = self._GetAndLockPluginTemplate('CiscoServices/imagemenu.html')
		try:
			tmpl.image = "/CiscoServices/images/phone.png"
			tmpl.baseurl = cherrypy.request.base
			return tmpl.RenderTemplate()
		finally:
			tmpl.ReleaseLock();
	imagemenu.exposed = True

